@@ -1,9 +1,11 @@
 package Mira::Model::Content;
 $Mira::Model::Content::VERSION = '0.07';
 
-use Data::Dumper;
+use strict;
+use warnings;
 use 5.012;
 
+use File::Spec;
 use File::Spec::Functions;
 use File::Basename qw/basename/;
 use Carp;
